@@ -1,10 +1,7 @@
 import logging
-import uuid
 
 import click
 
-from codecov_cli.fallbacks import CodecovOption, FallbackFieldEnum
-from codecov_cli.helpers.git import GitService
 from codecov_cli.helpers.options import global_options
 from codecov_cli.services.report import create_report_results_logic
 
@@ -23,7 +20,7 @@ def create_report_results(
     code: str,
     slug: str,
     git_service: str,
-    token: uuid.UUID,
+    token: str,
     fail_on_error: bool,
 ):
     enterprise_url = ctx.obj.get("enterprise_url")
