@@ -33,7 +33,8 @@ _global_upload_options = [
         "-s",
         "--dir",
         "--coverage-files-search-root-folder",
-        "coverage_files_search_root_folder",
+        "--files-search-root-folder",
+        "files_search_root_folder",
         help="Folder where to search for coverage files",
         type=click.Path(path_type=pathlib.Path),
         default=pathlib.Path.cwd,
@@ -42,7 +43,8 @@ _global_upload_options = [
     click.option(
         "--exclude",
         "--coverage-files-search-exclude-folder",
-        "coverage_files_search_exclude_folders",
+        "--files-search-exclude-folder",
+        "files_search_exclude_folders",
         help="Folders to exclude from search",
         type=click.Path(path_type=pathlib.Path),
         multiple=True,
@@ -52,7 +54,8 @@ _global_upload_options = [
         "-f",
         "--file",
         "--coverage-files-search-direct-file",
-        "coverage_files_search_explicitly_listed_files",
+        "--files-search-direct-file",
+        "files_search_explicitly_listed_files",
         help="Explicit files to upload. These will be added to the coverage files found for upload. If you wish to only upload the specified files, please consider using --disable-search to disable uploading other files.",
         type=click.Path(path_type=pathlib.Path),
         multiple=True,
@@ -60,7 +63,7 @@ _global_upload_options = [
     ),
     click.option(
         "--disable-search",
-        help="Disable search for coverage files. This is helpful when specifying what files you want to uload with the --file option.",
+        help="Disable search for coverage files. This is helpful when specifying what files you want to upload with the --file option.",
         is_flag=True,
         default=False,
     ),
@@ -95,6 +98,8 @@ _global_upload_options = [
         "-n",
         "--name",
         help="Custom defined name of the upload. Visible in Codecov UI",
+        cls=CodecovOption,
+        fallback_field=FallbackFieldEnum.build_code,
     ),
     click.option(
         "-B",
@@ -155,6 +160,20 @@ _global_upload_options = [
         is_flag=True,
         help="Raise no excpetions when no coverage reports found.",
     ),
+    click.option(
+        "--report-type",
+        help="The type of the file to upload, coverage by default. Possible values are: testing, coverage.",
+        default="coverage",
+        type=click.Choice(["coverage", "test_results"]),
+    ),
+    click.option(
+        "--network-filter",
+        help="Specify a filter on the files listed in the network section of the Codecov report. This will only add files whose path begin with the specified filter. Useful for upload-specific path fixing",
+    ),
+    click.option(
+        "--network-prefix",
+        help="Specify a prefix on files listed in the network section of the Codecov report. Useful to help resolve path fixing",
+    ),
 ]
 
 
@@ -172,28 +191,31 @@ def do_upload(
     ctx: click.Context,
     commit_sha: str,
     report_code: str,
+    branch: typing.Optional[str],
     build_code: typing.Optional[str],
     build_url: typing.Optional[str],
-    job_code: typing.Optional[str],
-    env_vars: typing.Dict[str, str],
-    flags: typing.List[str],
-    name: typing.Optional[str],
-    network_root_folder: pathlib.Path,
-    coverage_files_search_root_folder: pathlib.Path,
-    coverage_files_search_exclude_folders: typing.List[pathlib.Path],
-    coverage_files_search_explicitly_listed_files: typing.List[pathlib.Path],
-    disable_search: bool,
     disable_file_fixes: bool,
-    token: typing.Optional[str],
-    plugin_names: typing.List[str],
-    branch: typing.Optional[str],
-    slug: typing.Optional[str],
-    pull_request_number: typing.Optional[str],
-    use_legacy_uploader: bool,
-    fail_on_error: bool,
+    disable_search: bool,
     dry_run: bool,
+    env_vars: typing.Dict[str, str],
+    fail_on_error: bool,
+    files_search_exclude_folders: typing.List[pathlib.Path],
+    files_search_explicitly_listed_files: typing.List[pathlib.Path],
+    files_search_root_folder: pathlib.Path,
+    flags: typing.List[str],
     git_service: typing.Optional[str],
     handle_no_reports_found: bool,
+    job_code: typing.Optional[str],
+    name: typing.Optional[str],
+    network_filter: typing.Optional[str],
+    network_prefix: typing.Optional[str],
+    network_root_folder: pathlib.Path,
+    plugin_names: typing.List[str],
+    pull_request_number: typing.Optional[str],
+    report_type: str,
+    slug: typing.Optional[str],
+    token: typing.Optional[str],
+    use_legacy_uploader: bool,
 ):
     versioning_system = ctx.obj["versioning_system"]
     codecov_yaml = ctx.obj["codecov_yaml"] or {}
@@ -204,28 +226,31 @@ def do_upload(
         "Starting upload processing",
         extra=dict(
             extra_log_attributes=dict(
-                commit_sha=commit_sha,
-                report_code=report_code,
+                branch=branch,
                 build_code=build_code,
                 build_url=build_url,
-                job_code=job_code,
-                env_vars=env_vars,
-                flags=flags,
-                name=name,
-                network_root_folder=network_root_folder,
-                coverage_files_search_root_folder=coverage_files_search_root_folder,
-                coverage_files_search_exclude_folders=coverage_files_search_exclude_folders,
-                coverage_files_search_explicitly_listed_files=coverage_files_search_explicitly_listed_files,
-                plugin_names=plugin_names,
-                token=token,
-                branch=branch,
-                slug=slug,
-                pull_request_number=pull_request_number,
-                git_service=git_service,
-                enterprise_url=enterprise_url,
-                disable_search=disable_search,
+                commit_sha=commit_sha,
                 disable_file_fixes=disable_file_fixes,
+                disable_search=disable_search,
+                enterprise_url=enterprise_url,
+                env_vars=env_vars,
+                files_search_exclude_folders=files_search_exclude_folders,
+                files_search_explicitly_listed_files=files_search_explicitly_listed_files,
+                files_search_root_folder=files_search_root_folder,
+                flags=flags,
+                git_service=git_service,
                 handle_no_reports_found=handle_no_reports_found,
+                job_code=job_code,
+                name=name,
+                network_filter=network_filter,
+                network_prefix=network_prefix,
+                network_root_folder=network_root_folder,
+                plugin_names=plugin_names,
+                pull_request_number=pull_request_number,
+                report_code=report_code,
+                slug=slug,
+                token=token,
+                upload_file_type=report_type,
             )
         ),
     )
@@ -233,33 +258,32 @@ def do_upload(
         cli_config,
         versioning_system,
         ci_adapter,
-        commit_sha=commit_sha,
-        report_code=report_code,
+        branch=branch,
         build_code=build_code,
         build_url=build_url,
-        job_code=job_code,
-        env_vars=env_vars,
-        flags=flags,
-        name=name,
-        network_root_folder=network_root_folder,
-        coverage_files_search_root_folder=coverage_files_search_root_folder,
-        coverage_files_search_exclude_folders=list(
-            coverage_files_search_exclude_folders
-        ),
-        coverage_files_search_explicitly_listed_files=list(
-            coverage_files_search_explicitly_listed_files
-        ),
-        plugin_names=plugin_names,
-        token=token,
-        branch=branch,
-        slug=slug,
-        pull_request_number=pull_request_number,
-        use_legacy_uploader=use_legacy_uploader,
-        fail_on_error=fail_on_error,
-        dry_run=dry_run,
-        git_service=git_service,
-        enterprise_url=enterprise_url,
-        disable_search=disable_search,
-        handle_no_reports_found=handle_no_reports_found,
+        commit_sha=commit_sha,
         disable_file_fixes=disable_file_fixes,
+        disable_search=disable_search,
+        dry_run=dry_run,
+        enterprise_url=enterprise_url,
+        env_vars=env_vars,
+        fail_on_error=fail_on_error,
+        files_search_exclude_folders=list(files_search_exclude_folders),
+        files_search_explicitly_listed_files=list(files_search_explicitly_listed_files),
+        files_search_root_folder=files_search_root_folder,
+        flags=flags,
+        git_service=git_service,
+        handle_no_reports_found=handle_no_reports_found,
+        job_code=job_code,
+        name=name,
+        network_filter=network_filter,
+        network_prefix=network_prefix,
+        network_root_folder=network_root_folder,
+        plugin_names=plugin_names,
+        pull_request_number=pull_request_number,
+        report_code=report_code,
+        slug=slug,
+        token=token,
+        upload_file_type=report_type,
+        use_legacy_uploader=use_legacy_uploader,
     )
