@@ -31,10 +31,12 @@ def upload_process(
     env_vars: typing.Dict[str, str],
     flags: typing.List[str],
     name: typing.Optional[str],
+    network_filter: typing.Optional[str],
+    network_prefix: typing.Optional[str],
     network_root_folder: pathlib.Path,
-    coverage_files_search_root_folder: pathlib.Path,
-    coverage_files_search_exclude_folders: typing.List[pathlib.Path],
-    coverage_files_search_explicitly_listed_files: typing.List[pathlib.Path],
+    files_search_root_folder: pathlib.Path,
+    files_search_exclude_folders: typing.List[pathlib.Path],
+    files_search_explicitly_listed_files: typing.List[pathlib.Path],
     disable_search: bool,
     disable_file_fixes: bool,
     token: typing.Optional[str],
@@ -48,6 +50,7 @@ def upload_process(
     git_service: typing.Optional[str],
     parent_sha: typing.Optional[str],
     handle_no_reports_found: bool,
+    report_type: str,
 ):
     logger.debug(
         "Starting upload process",
@@ -61,10 +64,12 @@ def upload_process(
                 env_vars=env_vars,
                 flags=flags,
                 name=name,
+                network_filter=network_filter,
+                network_prefix=network_prefix,
                 network_root_folder=network_root_folder,
-                coverage_files_search_root_folder=coverage_files_search_root_folder,
-                coverage_files_search_exclude_folders=coverage_files_search_exclude_folders,
-                coverage_files_search_explicitly_listed_files=coverage_files_search_explicitly_listed_files,
+                files_search_root_folder=files_search_root_folder,
+                files_search_exclude_folders=files_search_exclude_folders,
+                files_search_explicitly_listed_files=files_search_explicitly_listed_files,
                 plugin_names=plugin_names,
                 token=token,
                 branch=branch,
@@ -90,15 +95,16 @@ def upload_process(
         git_service=git_service,
         fail_on_error=True,
     )
-    ctx.invoke(
-        create_report,
-        token=token,
-        code=report_code,
-        fail_on_error=True,
-        commit_sha=commit_sha,
-        slug=slug,
-        git_service=git_service,
-    )
+    if report_type == "coverage":
+        ctx.invoke(
+            create_report,
+            token=token,
+            code=report_code,
+            fail_on_error=True,
+            commit_sha=commit_sha,
+            slug=slug,
+            git_service=git_service,
+        )
     ctx.invoke(
         do_upload,
         commit_sha=commit_sha,
@@ -109,10 +115,12 @@ def upload_process(
         env_vars=env_vars,
         flags=flags,
         name=name,
+        network_filter=network_filter,
+        network_prefix=network_prefix,
         network_root_folder=network_root_folder,
-        coverage_files_search_root_folder=coverage_files_search_root_folder,
-        coverage_files_search_exclude_folders=coverage_files_search_exclude_folders,
-        coverage_files_search_explicitly_listed_files=coverage_files_search_explicitly_listed_files,
+        files_search_root_folder=files_search_root_folder,
+        files_search_exclude_folders=files_search_exclude_folders,
+        files_search_explicitly_listed_files=files_search_explicitly_listed_files,
         disable_search=disable_search,
         token=token,
         plugin_names=plugin_names,
@@ -125,4 +133,5 @@ def upload_process(
         git_service=git_service,
         handle_no_reports_found=handle_no_reports_found,
         disable_file_fixes=disable_file_fixes,
+        report_type=report_type,
     )
