@@ -11,6 +11,7 @@ from codecov_cli.commands.create_report_result import create_report_results
 from codecov_cli.commands.empty_upload import empty_upload
 from codecov_cli.commands.get_report_results import get_report_results
 from codecov_cli.commands.labelanalysis import label_analysis
+from codecov_cli.commands.process_test_results import process_test_results
 from codecov_cli.commands.report import create_report
 from codecov_cli.commands.send_notifications import send_notifications
 from codecov_cli.commands.staticanalysis import static_analysis
@@ -35,7 +36,7 @@ logger = logging.getLogger("codecovcli")
 @click.option(
     "--codecov-yml-path",
     type=click.Path(path_type=pathlib.Path),
-    default=pathlib.Path("codecov.yml"),
+    default=None,
 )
 @click.option(
     "--enterprise-url", "--url", "-u", help="Change the upload host (Enterprise use)"
@@ -57,6 +58,8 @@ def cli(
     ctx.obj["codecov_yaml"] = load_cli_config(codecov_yml_path)
     if ctx.obj["codecov_yaml"] is None:
         logger.debug("No codecov_yaml found")
+    elif (token := ctx.obj["codecov_yaml"].get("codecov", {}).get("token")) is not None:
+        ctx.default_map = {ctx.invoked_subcommand: {"token": token}}
     ctx.obj["enterprise_url"] = enterprise_url
 
 
@@ -71,6 +74,7 @@ cli.add_command(static_analysis)
 cli.add_command(empty_upload)
 cli.add_command(upload_process)
 cli.add_command(send_notifications)
+cli.add_command(process_test_results)
 
 
 def run():
