@@ -1,9 +1,9 @@
 import logging
+import os
 import typing
 
 from codecov_cli.helpers.config import CODECOV_API_URL
 from codecov_cli.helpers.encoder import decode_slug, encode_slug
-from codecov_cli.helpers.git import get_git_service, get_pull, is_fork_pr
 from codecov_cli.helpers.request import (
     get_token_header_or_fail,
     log_warnings_and_errors_if_any,
@@ -43,11 +43,12 @@ def create_commit_logic(
 def send_commit_data(
     commit_sha, parent_sha, pr, branch, slug, token, service, enterprise_url
 ):
-    decoded_slug = decode_slug(slug)
-    pull_dict = get_pull(service, decoded_slug, pr) if not token else None
-    if is_fork_pr(pull_dict):
-        headers = {"X-Tokenless": pull_dict["head"]["slug"]}
-        branch = pull_dict["head"]["slug"] + ":" + branch
+    # this is how the CLI receives the username of the user to whom the fork belongs
+    # to and the branch name from the action
+    tokenless = os.environ.get("TOKENLESS")
+    if tokenless:
+        headers = None  # type: ignore
+        branch = tokenless  # type: ignore
         logger.info("The PR is happening in a forked repo. Using tokenless upload.")
     else:
         headers = get_token_header_or_fail(token)
