@@ -7,8 +7,8 @@ import requests
 from codecov_cli.helpers import request
 from codecov_cli.helpers.config import CODECOV_API_URL
 from codecov_cli.helpers.encoder import decode_slug, encode_slug
-from codecov_cli.helpers.git import get_pull, is_fork_pr
 from codecov_cli.helpers.request import (
+    get_token_header,
     get_token_header_or_fail,
     log_warnings_and_errors_if_any,
     request_result,
@@ -47,14 +47,7 @@ def send_create_report_request(
     commit_sha, code, service, token, encoded_slug, enterprise_url, pull_request_number
 ):
     data = {"code": code}
-    decoded_slug = decode_slug(encoded_slug)
-    pull_dict = (
-        get_pull(service, decoded_slug, pull_request_number) if not token else None
-    )
-    if is_fork_pr(pull_dict):
-        headers = {"X-Tokenless": pull_dict["head"]["slug"]}
-    else:
-        headers = get_token_header_or_fail(token)
+    headers = get_token_header(token)
     upload_url = enterprise_url or CODECOV_API_URL
     url = f"{upload_url}/upload/{service}/{encoded_slug}/commits/{commit_sha}/reports"
     return send_post_request(url=url, headers=headers, data=data)
