@@ -9,7 +9,7 @@ from codecov_cli.helpers.ci_adapters.base import CIAdapterBase
 from codecov_cli.helpers.request import log_warnings_and_errors_if_any
 from codecov_cli.helpers.versioning_systems import VersioningSystemInterface
 from codecov_cli.plugins import select_preparation_plugins
-from codecov_cli.services.upload.coverage_file_finder import select_coverage_file_finder
+from codecov_cli.services.upload.file_finder import select_file_finder
 from codecov_cli.services.upload.legacy_upload_sender import LegacyUploadSender
 from codecov_cli.services.upload.network_finder import select_network_finder
 from codecov_cli.services.upload.upload_collector import UploadCollector
@@ -25,45 +25,57 @@ def do_upload_logic(
     versioning_system: VersioningSystemInterface,
     ci_adapter: CIAdapterBase,
     *,
-    commit_sha: str,
-    report_code: str,
+    branch: typing.Optional[str],
     build_code: typing.Optional[str],
     build_url: typing.Optional[str],
-    job_code: typing.Optional[str],
-    env_vars: typing.Dict[str, str],
-    flags: typing.List[str],
-    name: typing.Optional[str],
-    network_root_folder: Path,
-    coverage_files_search_root_folder: Path,
-    coverage_files_search_exclude_folders: typing.List[Path],
-    coverage_files_search_explicitly_listed_files: typing.List[Path],
-    plugin_names: typing.List[str],
-    token: str,
-    branch: typing.Optional[str],
-    slug: typing.Optional[str],
-    pull_request_number: typing.Optional[str],
-    use_legacy_uploader: bool = False,
-    fail_on_error: bool = False,
-    dry_run: bool = False,
-    git_service: typing.Optional[str],
-    enterprise_url: typing.Optional[str],
-    disable_search: bool = False,
-    handle_no_reports_found: bool = False,
+    commit_sha: str,
     disable_file_fixes: bool = False,
+    disable_search: bool = False,
+    dry_run: bool = False,
+    enterprise_url: typing.Optional[str],
+    env_vars: typing.Dict[str, str],
+    fail_on_error: bool = False,
+    files_search_exclude_folders: typing.List[Path],
+    files_search_explicitly_listed_files: typing.List[Path],
+    files_search_root_folder: Path,
+    flags: typing.List[str],
+    git_service: typing.Optional[str],
+    handle_no_reports_found: bool = False,
+    job_code: typing.Optional[str],
+    name: typing.Optional[str],
+    network_filter: typing.Optional[str],
+    network_prefix: typing.Optional[str],
+    network_root_folder: Path,
+    plugin_names: typing.List[str],
+    pull_request_number: typing.Optional[str],
+    report_code: str,
+    slug: typing.Optional[str],
+    token: str,
+    upload_file_type: str = "coverage",
+    use_legacy_uploader: bool = False,
 ):
-    preparation_plugins = select_preparation_plugins(cli_config, plugin_names)
-    coverage_file_selector = select_coverage_file_finder(
-        coverage_files_search_root_folder,
-        coverage_files_search_exclude_folders,
-        coverage_files_search_explicitly_listed_files,
+    if upload_file_type == "coverage":
+        preparation_plugins = select_preparation_plugins(cli_config, plugin_names)
+    elif upload_file_type == "test_results":
+        preparation_plugins = []
+    file_selector = select_file_finder(
+        files_search_root_folder,
+        files_search_exclude_folders,
+        files_search_explicitly_listed_files,
         disable_search,
+        upload_file_type,
+    )
+    network_finder = select_network_finder(
+        versioning_system,
+        network_filter=network_filter,
+        network_prefix=network_prefix,
+        network_root_folder=network_root_folder,
     )
-    network_finder = select_network_finder(versioning_system)
     collector = UploadCollector(
-        preparation_plugins, network_finder, coverage_file_selector, disable_file_fixes
+        preparation_plugins, network_finder, file_selector, disable_file_fixes
     )
     try:
-        upload_data = collector.generate_upload_data()
+        upload_data = collector.generate_upload_data(upload_file_type)
     except click.ClickException as exp:
         if handle_no_reports_found:
             logger.info(
@@ -103,6 +115,7 @@ def do_upload_logic(
             token,
             env_vars,
             report_code,
+            upload_file_type,
             name,
             branch,
             slug,
