@@ -8,7 +8,7 @@ from fnmatch import fnmatch
 
 import click
 
-from codecov_cli.services.upload.coverage_file_finder import CoverageFileFinder
+from codecov_cli.services.upload.file_finder import FileFinder
 from codecov_cli.services.upload.network_finder import NetworkFinder
 from codecov_cli.types import (
     PreparationPluginInterface,
@@ -28,24 +28,25 @@ class UploadCollector(object):
         self,
         preparation_plugins: typing.List[PreparationPluginInterface],
         network_finder: NetworkFinder,
-        coverage_file_finder: CoverageFileFinder,
+        file_finder: FileFinder,
         disable_file_fixes: bool = False,
     ):
         self.preparation_plugins = preparation_plugins
         self.network_finder = network_finder
-        self.coverage_file_finder = coverage_file_finder
+        self.file_finder = file_finder
         self.disable_file_fixes = disable_file_fixes
 
-    def _produce_file_fixes_for_network(
-        self, network: typing.List[str]
+    def _produce_file_fixes(
+        self, files: typing.List[str]
     ) -> typing.List[UploadCollectionResultFileFixer]:
-        if not network or self.disable_file_fixes:
+        if not files or self.disable_file_fixes:
             return []
         # patterns that we don't need to specify a reason for
         empty_line_regex = re.compile(r"^\s*$")
         comment_regex = re.compile(r"^\s*\/\/.*$")
         bracket_regex = re.compile(r"^\s*[\{\}]\s*(\/\/.*)?$")
         list_regex = re.compile(r"^\s*[\]\[]\s*(\/\/.*)?$")
+        parenthesis_regex = re.compile(r"^\s*[\(\)]\s*(\/\/.*)?$")
         go_function_regex = re.compile(r"^\s*func\s*[\{]\s*(\/\/.*)?$")
         php_end_bracket_regex = re.compile(r"^\s*\);\s*(\/\/.*)?$")
 
@@ -54,7 +55,7 @@ class UploadCollector(object):
         lcov_excel_regex = re.compile(r"\/\/ LCOV_EXCL")
 
         kt_patterns_to_apply = fix_patterns_to_apply(
-            [bracket_regex], [comment_block_regex], True
+            [bracket_regex, parenthesis_regex], [comment_block_regex], True
         )
         go_patterns_to_apply = fix_patterns_to_apply(
             [empty_line_regex, comment_regex, bracket_regex, go_function_regex],
@@ -71,7 +72,6 @@ class UploadCollector(object):
             [],
             False,
         )
-
         cpp_swift_vala_patterns_to_apply = fix_patterns_to_apply(
             [empty_line_regex, bracket_regex],
             [lcov_excel_regex],
@@ -94,7 +94,7 @@ class UploadCollector(object):
         }
 
         result = []
-        for filename in network:
+        for filename in files:
             for glob, fix_patterns in file_regex_patterns.items():
                 if fnmatch(filename, glob):
                     result.append(self._get_file_fixes(filename, fix_patterns))
@@ -139,30 +139,40 @@ class UploadCollector(object):
                     reason=err.reason,
                 ),
             )
+        except IsADirectoryError as err:
+            logger.info(f"Skipping {filename}, found a directory not a file")
 
         return UploadCollectionResultFileFixer(
             path, fixed_lines_without_reason, fixed_lines_with_reason, eof
         )
 
-    def generate_upload_data(self) -> UploadCollectionResult:
+    def generate_upload_data(self, report_type="coverage") -> UploadCollectionResult:
         for prep in self.preparation_plugins:
             logger.debug(f"Running preparation plugin: {type(prep)}")
             prep.run_preparation(self)
         logger.debug("Collecting relevant files")
         network = self.network_finder.find_files()
-        coverage_files = self.coverage_file_finder.find_coverage_files()
-        logger.info(f"Found {len(coverage_files)} coverage files to upload")
-        if not coverage_files:
+        report_files = self.file_finder.find_files()
+        logger.info(f"Found {len(report_files)} {report_type} files to report")
+        if not report_files:
+            if report_type == "test_results":
+                error_message = "No JUnit XML reports found. Please review our documentation (https://docs.codecov.com/docs/test-result-ingestion-beta) to generate and upload the file."
+            else:
+                error_message = "No coverage reports found. Please make sure you're generating reports successfully."
             raise click.ClickException(
                 click.style(
-                    "No coverage reports found. Please make sure you're generating reports successfully.",
+                    error_message,
                     fg="red",
                 )
             )
-        for file in coverage_files:
+        for file in report_files:
             logger.info(f"> {file}")
         return UploadCollectionResult(
             network=network,
-            coverage_files=coverage_files,
-            file_fixes=self._produce_file_fixes_for_network(network),
+            files=report_files,
+            file_fixes=(
+                self._produce_file_fixes(self.network_finder.find_files(True))
+                if report_type == "coverage"
+                else []
+            ),
         )
