@@ -8,9 +8,8 @@ from typing import Any, Dict
 from codecov_cli import __version__ as codecov_cli_version
 from codecov_cli.helpers.config import CODECOV_API_URL
 from codecov_cli.helpers.encoder import encode_slug
-from codecov_cli.helpers.git import get_pull, is_fork_pr
 from codecov_cli.helpers.request import (
-    get_token_header_or_fail,
+    get_token_header,
     send_post_request,
     send_put_request,
 )
@@ -31,6 +30,7 @@ class UploadSender(object):
         token: str,
         env_vars: typing.Dict[str, str],
         report_code: str,
+        upload_file_type: str = "coverage",
         name: typing.Optional[str] = None,
         branch: typing.Optional[str] = None,
         slug: typing.Optional[str] = None,
@@ -50,22 +50,24 @@ class UploadSender(object):
             "name": name,
             "job_code": job_code,
             "version": codecov_cli_version,
+            "ci_service": ci_service,
         }
-
-        # Data to upload to Codecov
-        pull_dict = (
-            get_pull(git_service, slug, pull_request_number) if not token else None
-        )
-
-        if is_fork_pr(pull_dict):
-            headers = {"X-Tokenless": pull_dict["head"]["slug"]}
-        else:
-            headers = get_token_header_or_fail(token)
+        headers = get_token_header(token)
         encoded_slug = encode_slug(slug)
         upload_url = enterprise_url or CODECOV_API_URL
-        url = f"{upload_url}/upload/{git_service}/{encoded_slug}/commits/{commit_sha}/reports/{report_code}/uploads"
+        url, data = self.get_url_and_possibly_update_data(
+            data,
+            upload_file_type,
+            upload_url,
+            git_service,
+            encoded_slug,
+            commit_sha,
+            report_code,
+        )
         # Data that goes to storage
-        reports_payload = self._generate_payload(upload_data, env_vars)
+        reports_payload = self._generate_payload(
+            upload_data, env_vars, upload_file_type
+        )
 
         logger.debug("Sending upload request to Codecov")
         resp_from_codecov = send_post_request(
@@ -90,18 +92,26 @@ class UploadSender(object):
         return resp_from_storage
 
     def _generate_payload(
-        self, upload_data: UploadCollectionResult, env_vars: typing.Dict[str, str]
+        self,
+        upload_data: UploadCollectionResult,
+        env_vars: typing.Dict[str, str],
+        upload_file_type="coverage",
     ) -> bytes:
         network_files = upload_data.network
-        payload = {
-            "report_fixes": {
-                "format": "legacy",
-                "value": self._get_file_fixers(upload_data),
-            },
-            "network_files": network_files if network_files is not None else [],
-            "coverage_files": self._get_coverage_files(upload_data),
-            "metadata": {},
-        }
+        if upload_file_type == "coverage":
+            payload = {
+                "report_fixes": {
+                    "format": "legacy",
+                    "value": self._get_file_fixers(upload_data),
+                },
+                "network_files": network_files if network_files is not None else [],
+                "coverage_files": self._get_files(upload_data),
+                "metadata": {},
+            }
+        elif upload_file_type == "test_results":
+            payload = {
+                "test_results_files": self._get_files(upload_data),
+            }
 
         json_data = json.dumps(payload)
         return json_data.encode()
@@ -134,10 +144,10 @@ class UploadSender(object):
 
         return file_fixers
 
-    def _get_coverage_files(self, upload_data: UploadCollectionResult):
-        return [self._format_coverage_file(file) for file in upload_data.coverage_files]
+    def _get_files(self, upload_data: UploadCollectionResult):
+        return [self._format_file(file) for file in upload_data.files]
 
-    def _format_coverage_file(self, file: UploadCollectionResultFile):
+    def _format_file(self, file: UploadCollectionResultFile):
         format, formatted_content = self._get_format_info(file)
         return {
             "filename": file.get_filename().decode(),
@@ -152,3 +162,23 @@ class UploadSender(object):
             base64.b64encode(zlib.compress((file.get_content())))
         ).decode()
         return format, formatted_content
+
+    def get_url_and_possibly_update_data(
+        self,
+        data,
+        report_type,
+        upload_url,
+        git_service,
+        encoded_slug,
+        commit_sha,
+        report_code,
+    ):
+        if report_type == "coverage":
+            url = f"{upload_url}/upload/{git_service}/{encoded_slug}/commits/{commit_sha}/reports/{report_code}/uploads"
+        elif report_type == "test_results":
+            data["slug"] = encoded_slug
+            data["commit"] = commit_sha
+            data["service"] = git_service
+            url = f"{upload_url}/upload/test_results/v1"
+
+        return url, data
